aerosoltools.aerosol1d.Aerosol1D.timeshift — aerosoltools 0.1.0 documentation

# aerosoltools.aerosol1d.Aerosol1D.timeshift

Aerosol1D.timeshift(seconds=0, minutes=0, hours=0, inplace=True)

  Shift the time index by a given number of seconds and/or minutes.

  ## Parameters

  secondsfloat, optional

    Number of seconds to shift. Defaults to 0.

  minutesfloat, optional

    Number of minutes to shift. Defaults to 0.

  inplacebool, optional

    Whether to modify the object in place. Defaults to True.

  ## Returns

  Aerosol1D

    Instance of Aerosol1D with shifted time index. Either the modified current object (if inplace=True) or a new shifted object (if inplace=False).

  Parameters:

    - seconds (float)

    - minutes (float)

    - hours (float)

    - inplace (bool)